package com.dzeio.openhealth.ui.home

import android.app.Activity.RESULT_OK
import android.content.Intent
import android.content.pm.PackageManager
import android.os.Build
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.lifecycle.ViewModelProvider
import com.dzeio.openhealth.connectors.ActionRequestCode
import com.dzeio.openhealth.connectors.GoogleFit
import com.dzeio.openhealth.connectors.samsunghealth.SamsungHealth
import com.dzeio.openhealth.databinding.FragmentHomeBinding
import com.dzeio.openhealth.db.AppDatabase

class HomeFragment : Fragment() {

    companion object {
        const val TAG = "HomeFragment"
    }

    private var _binding: FragmentHomeBinding? = null

    // This property is only valid between onCreateView and
    // onDestroyView.
    private val binding get() = _binding!!

    private lateinit var fit: GoogleFit

    private lateinit var viewModel: HomeViewModel

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        viewModel =
            ViewModelProvider(this).get(HomeViewModel::class.java)

        _binding = FragmentHomeBinding.inflate(inflater, container, false)
        val root: View = binding.root

//        binding.button.setOnClickListener {
//            fit = GoogleFit(requireActivity())
//            //fit.import()
//            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
//                //fit.getHistory()
//                fit.importWeight()
//            }
//
//            //SamsungHealth(requireActivity()).importStepCount()
//        }
        viewModel.text.observe(viewLifecycleOwner) {
            binding.textView2.text = it
        }


        return root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val weight = AppDatabase.getInstance(requireContext()).weightDao().last()
        if (weight == null) {
            viewModel.text.postValue("No Weight Available")
        } else {
            viewModel.text.postValue("${weight.weight}kg\ndone at ${weight.timestamp}")
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        Log.d(TAG, "Activity Result!")
        when (resultCode) {
            RESULT_OK -> {
                fit.performActionForRequestCode(ActionRequestCode.FIND_DATA_SOURCES)
            }
            else -> {
                Log.e(TAG, "Error: $requestCode, $resultCode")
            }
        }
    }

    override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String>,
                                            grantResults: IntArray) {
        when {
            grantResults.isEmpty() -> {
                // If user interaction was interrupted, the permission request
                // is cancelled and you receive empty arrays.
                Log.i(TAG, "User interaction was cancelled.")
            }

                    grantResults[0] == PackageManager.PERMISSION_GRANTED -> {
                        Log.d(TAG, "Granted")
                // Permission was granted.
                val fitActionRequestCode = ActionRequestCode.values()[requestCode]
                fitActionRequestCode.let {
                    fit.signIn(ActionRequestCode.FIND_DATA_SOURCES)
                }
            }
            else -> {
                // Permission denied.

                // In this Activity we've chosen to notify the user that they
                // have rejected a core permission for the app since it makes the Activity useless.
                // We're communicating this message in a Snackbar since this is a sample app, but
                // core permissions would typically be best requested during a welcome-screen flow.

                // Additionally, it is important to remember that a permission might have been
                // rejected without asking the user for permission (device policy or "Never ask
                // again" prompts). Therefore, a user interface affordance is typically implemented
                // when permissions are denied. Otherwise, your app could appear unresponsive to
                // touches or interactions which have required permissions.
                Log.e(TAG, "Error")
//                Snackbar.make(
//                    findViewById(R.id.main_activity_view),
//                    R.string.permission_denied_explanation,
//                    Snackbar.LENGTH_INDEFINITE)
//                    .setAction(R.string.settings) {
//                        // Build intent that displays the App settings screen.
//                        val intent = Intent()
//                        intent.action = Settings.ACTION_APPLICATION_DETAILS_SETTINGS
//                        val uri = Uri.fromParts("package",
//                            BuildConfig.APPLICATION_ID, null)
//                        intent.data = uri
//                        intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
//                        startActivity(intent)
//                    }
//                    .show()
            }
        }
    }
}